@@ -28,9 +28,9 @@ class Crawler:
         scraper = Scraper(response)
         list_href = scraper.gethref()
         if list_href.count == 0: return None
-        urls = list_href.map(lambda x: x.url())
-        urls.ForEach(lambda x: Terminal.found(x))
-        responses = self.fetcher.get_all_pages(urls)
+        list_href.map(lambda x: x.url())
+        list_href.forEach(lambda x: Terminal.found(x))
+        responses = self.fetcher.get_all_pages(list_href)
         responses.removeErrors()
         return responses
     
