@@ -12,7 +12,7 @@ class Response(ResponseType):
         try: 
             split = self.url.split(".")
             domain = split[1]
-            TLD = split.split("/")[0]
+            TLD = split[2].split("/")[0]
             return domain + "." + TLD
         except:
             return None
